pub struct HttpError { /* private fields */ }Expand description
An unsuccessful HTTP response
Implementations
Sourceimpl HttpError
impl HttpError
Sourcepub async fn new(response: Response) -> Self
pub async fn new(response: Response) -> Self
Create an error from an http response.
This does not check whether the response was a success and should only be used with unsuccessful responses.
Sourcepub fn status(&self) -> StatusCode
pub fn status(&self) -> StatusCode
Get the status code for the http error
Sourcepub fn error_code(&self) -> Option<&str>
pub fn error_code(&self) -> Option<&str>
Get a reference to the http error’s error code.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
Get a reference to the http error’s error message.