Headers

Struct Headers 

pub struct Headers(/* private fields */);
A collection of headers

Implementations

Source

impl Headers

pub fn new() -> Self

pub fn get_optional_string(&self, key: &HeaderName) -> Option<String>

Optionally get a header value as a String

pub fn get_str(&self, key: &HeaderName) -> Result<&str>

Get a header value as a str or error if it is not found

pub fn get_optional_str(&self, key: &HeaderName) -> Option<&str>

Optionally get a header value as a str

pub fn get_as<V, E>(&self, key: &HeaderName) -> Result<V>
where V: FromStr<Err = E>, E: Error + Send + Sync + 'static,

Get a header value parsing it as the type or error if it’s not found or it fails to parse

pub fn get_optional_as<V, E>(&self, key: &HeaderName) -> Result<Option<V>>
where V: FromStr<Err = E>, E: Error + Send + Sync + 'static,

Optionally get a header value parsing it as the type or error if it fails to parse

pub fn get_with<'a, V, F, E>(&'a self, key: &HeaderName, parser: F) -> Result<V>
where F: FnOnce(&'a HeaderValue) -> Result<V, E>, E: Error + Send + Sync + 'static,

Get a header value using the parser or error if it is not found or fails to parse

pub fn get_optional_with<'a, V, F, E>( &'a self, key: &HeaderName, parser: F, ) -> Result<Option<V>>
where F: FnOnce(&'a HeaderValue) -> Result<V, E>, E: Error + Send + Sync + 'static,

Optionally get a header value using the parser or error if it fails to parse

pub fn insert<K, V>(&mut self, key: K, value: V)

Insert a header name/value pair

pub fn add<H>(&mut self, header: H)
where H: AsHeaders,

Add headers to the headers collection

pub fn iter(&self) -> impl Iterator<Item = (&HeaderName, &HeaderValue)>

Iterate over all the header name/value pairs