pub struct TelemetryPolicy { /* private fields */ }Implementations
Sourceimpl<'a> TelemetryPolicy
Sets the User-Agent header with useful information in a typical format for Azure SDKs.
impl<'a> TelemetryPolicy
Sets the User-Agent header with useful information in a typical format for Azure SDKs.